@@ -25,8 +25,8 @@
  * This map source source downloads the map data from an OpenStreetMap API
  * server. It supports protocol version 0.5 and 0.6.
  *
- * <ulink role="online-location" url="http://wiki.openstreetmap.org/wiki/API">
- * http://wiki.openstreetmap.org/wiki/API</ulink>
+ * <ulink role="online-location" url="https://wiki.openstreetmap.org/wiki/API">
+ * https://wiki.openstreetmap.org/wiki/API</ulink>
  */
 
 #include "champlain-network-bbox-tile-source.h"
@@ -40,10 +40,15 @@
 
 #include <libsoup/soup.h>
 
-G_DEFINE_TYPE (ChamplainNetworkBboxTileSource, champlain_network_bbox_tile_source, CHAMPLAIN_TYPE_TILE_SOURCE)
+struct _ChamplainNetworkBboxTileSourcePrivate
+{
+  gchar *api_uri;
+  gchar *proxy_uri;
+  SoupSession *soup_session;
+  ChamplainState state;
+};
 
-#define GET_PRIVATE(o) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((o), CHAMPLAIN_TYPE_NETWORK_BBOX_TILE_SOURCE, ChamplainNetworkBboxTileSourcePrivate))
+G_DEFINE_TYPE_WITH_PRIVATE (ChamplainNetworkBboxTileSource, champlain_network_bbox_tile_source, CHAMPLAIN_TYPE_TILE_SOURCE)
 
 enum
 {
@@ -54,14 +59,6 @@ enum
   PROP_USER_AGENT
 };
 
-struct _ChamplainNetworkBboxTileSourcePrivate
-{
-  gchar *api_uri;
-  gchar *proxy_uri;
-  SoupSession *soup_session;
-  ChamplainState state;
-};
-
 static void fill_tile (ChamplainMapSource *map_source,
     ChamplainTile *tile);
 
@@ -175,8 +172,6 @@ champlain_network_bbox_tile_source_class_init (ChamplainNetworkBboxTileSourceCla
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (ChamplainNetworkBboxTileSourcePrivate));
-
   object_class->get_property = champlain_network_bbox_tile_source_get_property;
   object_class->set_property = champlain_network_bbox_tile_source_set_property;
   object_class->dispose = champlain_network_bbox_tile_source_dispose;
@@ -197,7 +192,7 @@ champlain_network_bbox_tile_source_class_init (ChamplainNetworkBboxTileSourceCla
       g_param_spec_string ("api-uri",
           "API URI",
           "The API URI of an OpenStreetMap server",
-          "http://www.informationfreeway.org/api/0.6",
+          "https://www.informationfreeway.org/api/0.6",
           G_PARAM_READWRITE));
 
   /**
@@ -252,11 +247,11 @@ champlain_network_bbox_tile_source_class_init (ChamplainNetworkBboxTileSourceCla
 static void
 champlain_network_bbox_tile_source_init (ChamplainNetworkBboxTileSource *self)
 {
-  ChamplainNetworkBboxTileSourcePrivate *priv = GET_PRIVATE (self);
+  ChamplainNetworkBboxTileSourcePrivate *priv = champlain_network_bbox_tile_source_get_instance_private (self);
 
   self->priv = priv;
 
-  priv->api_uri = g_strdup ("http://www.informationfreeway.org/api/0.6");
+  priv->api_uri = g_strdup ("https://www.informationfreeway.org/api/0.6");
   /* informationfreeway.org is a load-balancer for different api servers */
   priv->proxy_uri = g_strdup ("");
   priv->soup_session = soup_session_new_with_options (
@@ -339,7 +334,7 @@ load_map_data_cb (G_GNUC_UNUSED SoupSession *session, SoupMessage *msg,
   g_object_set (G_OBJECT (self), "state", CHAMPLAIN_STATE_DONE, NULL);
 
   renderer = champlain_map_source_get_renderer (CHAMPLAIN_MAP_SOURCE (self));
-  champlain_renderer_set_data (renderer, msg->response_body->data, msg->response_body->length);
+  champlain_renderer_set_data (renderer, (guint8*) msg->response_body->data, msg->response_body->length);
 }
 
 
@@ -353,8 +348,8 @@ load_map_data_cb (G_GNUC_UNUSED SoupSession *session, SoupMessage *msg,
  * limitations on the maximum number of nodes that can be requested.
  *
  * For details, see: <ulink role="online-location"
- * url="http://api.openstreetmap.org/api/capabilities">
- * http://api.openstreetmap.org/api/capabilities</ulink>
+ * url="https://api.openstreetmap.org/api/capabilities">
+ * https://api.openstreetmap.org/api/capabilities</ulink>
  *
  * Since: 0.10
  */
@@ -373,7 +368,7 @@ champlain_network_bbox_tile_source_load_map_data (
   gchar *url;
 
   url = g_strdup_printf (
-        "http://api.openstreetmap.org/api/0.6/map?bbox=%f,%f,%f,%f",
+        "https://api.openstreetmap.org/api/0.6/map?bbox=%f,%f,%f,%f",
         bbox->left, bbox->bottom, bbox->right, bbox->top);
   msg = soup_message_new ("GET", url);
 
